import { BedrockEmbeddingModel } from './bedrock-embedding-model';
import { BedrockRuntimeClient } from '@aws-sdk/client-bedrock-runtime';
import {
    BaseEmbedding,
    BaseEmbeddingAdditionalParams,
    TextSplitter,
} from './base-embedding';

/**
 * Abstract class representing a base implementation for Amazon Bedrock embedding services.
 * This class extends BaseEmbedding and provides common functionality for interacting
 * with Amazon Bedrock embedding models via the AWS SDK.
 *
 * @typeParam TAdditionalParams - Type extending BaseEmbeddingAdditionalParams for model-specific parameters
 */
export declare abstract class BedrockEmbedding<
    TAdditionalParams extends BaseEmbeddingAdditionalParams,
> extends BaseEmbedding<TAdditionalParams> {
    /**
     * The AWS Bedrock Runtime client used to make API calls to the Bedrock service
     */
    protected readonly client: BedrockRuntimeClient;
    
    /**
     * The embedding model identifier used for API calls
     */
    protected readonly model: BedrockEmbeddingModel;

    /**
     * Creates a new instance of BedrockEmbedding
     * 
     * @param accessKeyId - AWS access key ID for authentication
     * @param secretAccessKey - AWS secret access key for authentication
     * @param region - AWS region where the Bedrock service is hosted
     * @param model - The specific Bedrock embedding model to use
     * @param textSplitter - The text splitting strategy to use for processing input text
     */
    constructor(
        accessKeyId: string,
        secretAccessKey: string,
        region: string,
        model: BedrockEmbeddingModel,
        textSplitter: TextSplitter,
    );
}