/**
 * Enum representing different versions of Bedrock models provided by various vendors.
 * These models include Anthropic's Claude series, Amazon's Nova, and DeepSeek models.
 *
 * Members:
 * - BEDROCK_ANTHROPIC_CLAUDE_3_HAIKU: Represents the Claude 3 Haiku model version with a specific timestamp and identifier.
 * - BEDROCK_ANTHROPIC_CLAUDE_3_5_HAIKU: Represents the Claude 3.5 Haiku model version available under a specific timestamp and identifier.
 * - BEDROCK_ANTHROPIC_CLAUDE_3_5_SONNET: Represents the Claude 3.5 Sonnet model with a specific timestamp and identifier.
 * - BEDROCK_ANTHROPIC_CLAUDE_3_5_SONNET_V2: Represents the Claude 3.5 Sonnet V2 model with enhanced capabilities.
 * - BEDROCK_ANTHROPIC_CLAUDE_3_7_SONNET: Represents the Claude 3.7 Sonnet model version identified by its timestamp and unique identifier.
 * - BEDROCK_ANTHROPIC_CLAUDE_4_0_SONNET: Represents the Claude 4.0 Sonnet model with advanced features and improvements.
 * - BEDROCK_ANTHROPIC_CLAUDE_4_0_OPUS: Represents the Claude 4.0 Opus model, offering superior performance and capabilities.
 * - AMAZON_NOVA_PRO_V1: Represents Amazon's Nova Pro model version 1 with professional capabilities.
 * - AMAZON_NOVA_PREMIERE_V1: Represents Amazon's Nova Premiere model version 1 with enhanced features.
 * - DEEPSEEK_R1_V1: Represents DeepSeek's R1 model version 1 for advanced text processing.
 */
export declare enum BedrockLlmModel {
    BEDROCK_ANTHROPIC_CLAUDE_3_HAIKU = 'anthropic.claude-3-haiku-20240307-v1:0',
    BEDROCK_ANTHROPIC_CLAUDE_3_5_HAIKU = 'us.anthropic.claude-3-5-haiku-20241022-v1:0',
    BEDROCK_ANTHROPIC_CLAUDE_3_5_SONNET = 'anthropic.claude-3-5-sonnet-20240620-v1:0',
    BEDROCK_ANTHROPIC_CLAUDE_3_5_SONNET_V2 = 'us.anthropic.claude-3-5-sonnet-20241022-v2:0',
    BEDROCK_ANTHROPIC_CLAUDE_3_7_SONNET = 'us.anthropic.claude-3-7-sonnet-20250219-v1:0',
    BEDROCK_ANTHROPIC_CLAUDE_4_0_SONNET = 'us.anthropic.claude-sonnet-4-20250514-v1:0',
    BEDROCK_ANTHROPIC_CLAUDE_4_0_OPUS = 'us.anthropic.claude-opus-4-20250514-v1:0',
    AMAZON_NOVA_PRO_V1 = 'us.amazon.nova-pro-v1:0',
    AMAZON_NOVA_PREMIERE_V1 = 'us.amazon.nova-premier-v1:0',
    DEEPSEEK_R1_V1 = 'us.deepseek.r1-v1:0',
}
